hal/hald/linux2 osspec.c,1.44,1.45

Danny Kukawka dkukawka at freedesktop.org
Mon Feb 13 08:42:34 PST 2006


Update of /cvs/hal/hal/hald/linux2
In directory gabe:/tmp/cvs-serv14015/hald/linux2

Modified Files:
	osspec.c 
Log Message:
2006-02-13  Danny Kukawka  <danny.kukawka at web.de>

        * hald/linux2/osspec.c: (computer_probing_pcbios_helper_done):
        fix mapping system.formfactor from smbios



Index: osspec.c
===================================================================
RCS file: /cvs/hal/hal/hald/linux2/osspec.c,v
retrieving revision 1.44
retrieving revision 1.45
diff -u -d -r1.44 -r1.45
--- osspec.c	12 Feb 2006 21:47:28 -0000	1.44
+++ osspec.c	13 Feb 2006 16:42:32 -0000	1.45
@@ -426,8 +426,8 @@
 
 		for (i = 0; chassis_map[i] != NULL; i += 2) {
 			if (strcmp (chassis_map[i], chassis_type) == 0) {
-				/* check if the key is already set to prevent overwrite keys */
-				if (!hal_device_has_property(d, "system.formfactor"))
+				/* check if the key is 'unknown' to prevent overwrite keys */
+				if (strcmp (hal_device_property_get_string (d, "system.formfactor"), "unknown"))
 					hal_device_property_set_string (d, "system.formfactor", chassis_map[i+1]);
 				break;
 			}




More information about the hal-commit mailing list